// Toggle accordion section with dynamic max-height
function toggleSection(header) {
  const currentContent = header.nextElementSibling;
  const allContents = document.querySelectorAll(".content");
  const allHeaders = document.querySelectorAll(".accordion-item h3");

  // Close all other sections except the current one
  allContents.forEach((content) => {
    if (content !== currentContent) {
      content.style.maxHeight = null;
      content.classList.remove("open");
      content.previousElementSibling.classList.remove("open");
    }
  });

  // Toggle the current section
  currentContent.classList.toggle("open");
  header.classList.toggle("open");

  // Set max-height based on scrollHeight for smooth expansion
  if (currentContent.classList.contains("open")) {
    currentContent.style.maxHeight = currentContent.scrollHeight + "px";
  } else {
    currentContent.style.maxHeight = null;
  }

  // Update icons
  updateIcons();
}

// Update the toggle icons based on content state
function updateIcons() {
  const headers = document.querySelectorAll(".accordion-item h3");
  headers.forEach((header) => {
    const icon = header.querySelector(".toggle-icon");
    icon.textContent = header.classList.contains("open") ? "-" : "+";
  });
}

// Update item counts in each section
function updateItemCounts() {
  const accordionItems = document.querySelectorAll(".accordion-item");
  accordionItems.forEach((item) => {
    const content = item.querySelector(".content");
    const countSpan = item.querySelector(".count");
    const itemCount = content.querySelectorAll("p").length;
    countSpan.textContent = itemCount;
  });
}

// Run functions on page load
document.addEventListener("DOMContentLoaded", () => {
  updateItemCounts();
  updateIcons();
});
